ICECS 2012 paper by Callegari and Bizzarri
-------------------------------------------

This section illustrates how to replicate the results presented in the
paper [Cal12]_.

.. [Cal12] Sergio Callegari, Federico Bizzarri *"Should ΔΣ modulators
   used in AC motor drives be adapted to the mechanical load of the
   motor?"*, Proceedings of the 19th IEEE International Conference on
   Electronics, Circuits and Systems (ICECS), 2012,
   pp. 849 - 852. DOI: `10.1109/ICECS.2012.6463619
   <http://dx.doi.org/10.1109/ICECS.2012.6463619>`_, also available on
   `arXiv <http://arxiv.org/abs/1302.7172>`__

To this aim, some sample code is provided in the directory
``Examples/ICECS-2012``.

The sample code reproduces the plots in Figs. 2 and 4 in the paper.
Furthermore, it outputs tabular data including that in Tables II and III.

With respect to the numeric data, note that the discrete time
simulations of the digital delta sigma modulator include some random
dithering. Thus the numeric data will never be identical to that in the paper.
